==> realestate-supervise-common-1.0.0-20190527.033121-2-sources.jar: cn/gtmap/realestate/supervise/entity/XtGroup.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;


/**
 * @author zhangyu
 * @version 1.0, 2017/5/25
 * @description
 */
@Table(name = "XT_GROUP")
public class XtGroup implements Serializable {
    @Id
    private String groupId;
    private String groupName;
    private String groupNo;
    private String menuType;
    private String groupDes;
    private String groupOrder;
    private String groupUrl;


    public String getGroupId() {
        return groupId;
    }

    public void setGroupId(String groupId) {
        this.groupId = groupId;
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName;
    }

    public String getGroupNo() {
        return groupNo;
    }

    public void setGroupNo(String groupNo) {
        this.groupNo = groupNo;
    }

    public String getMenuType() {
        return menuType;
    }

    public void setMenuType(String menuType) {
        this.menuType = menuType;
    }

    public String getGroupDes() {
        return groupDes;
    }

    public void setGroupDes(String groupDes) {
        this.groupDes = groupDes;
    }

    public String getGroupOrder() {
        return groupOrder;
    }

    public void setGroupOrder(String groupOrder) {
        this.groupOrder = groupOrder;
    }

    public String getGroupUrl() {
        return groupUrl;
    }

    public void setGroupUrl(String groupUrl) {
        this.groupUrl = groupUrl;
    }
}

==> realestate-supervise-common-1.1.0-20220326.075841-9-sources.jar: cn/gtmap/realestate/supervise/entity/XtGroup.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;


/**
 * @author zhangyu
 * @version 1.0, 2017/5/25
 * @description
 */
@Table(name = "XT_GROUP")
public class XtGroup implements Serializable {
    @Id
    private String groupId;
    private String groupName;
    private String groupNo;
    private String menuType;
    private String groupDes;
    private String groupOrder;
    private String groupUrl;


    public String getGroupId() {
        return groupId;
    }

    public void setGroupId(String groupId) {
        this.groupId = groupId;
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName;
    }

    public String getGroupNo() {
        return groupNo;
    }

    public void setGroupNo(String groupNo) {
        this.groupNo = groupNo;
    }

    public String getMenuType() {
        return menuType;
    }

    public void setMenuType(String menuType) {
        this.menuType = menuType;
    }

    public String getGroupDes() {
        return groupDes;
    }

    public void setGroupDes(String groupDes) {
        this.groupDes = groupDes;
    }

    public String getGroupOrder() {
        return groupOrder;
    }

    public void setGroupOrder(String groupOrder) {
        this.groupOrder = groupOrder;
    }

    public String getGroupUrl() {
        return groupUrl;
    }

    public void setGroupUrl(String groupUrl) {
        this.groupUrl = groupUrl;
    }

    @Override
    public String toString() {
        return "XtGroup{" +
            "groupId='" + groupId + '\'' +
            ", groupName='" + groupName + '\'' +
            ", groupNo='" + groupNo + '\'' +
            ", menuType='" + menuType + '\'' +
            ", groupDes='" + groupDes + '\'' +
            ", groupOrder='" + groupOrder + '\'' +
            ", groupUrl='" + groupUrl + '\'' +
            '}';
    }
}
